## [2.0.1] - 2025-09-03

### Added
- Add include_path for custom includes
- Add copier template

### Changed
- Merge pull request #1 from clearskies-py/copier by @tnijboer in [#1](https://github.com/clearskies-py/doc-builder/pull/1)
- Update for tooling by @cmancone
- WIP by @cmancone
- Initial commit by @cmancone

## New Contributors
* @ made their first contribution
* @tnijboer made their first contribution in [#1](https://github.com/clearskies-py/doc-builder/pull/1)
* @cmancone made their first contribution
